"use client";

import "./SignInForm.scss";
import { useEffect, useState } from "react";
import InputWithLabel from "@/Entities/InputWithLabel/InputWithLabel";
import Button from "@/Shared/UI/Button/Button";
import { useRouter } from "next/navigation";
import CustomLink from "@/Entities/CustomLink/CustomLink";
import GoogleButton from "@/Entities/GoogleButton/GoogleButton";
import { useSignIn } from "./sign-in.store";
import DefaultLoader from "@/Shared/UI/DefaultLoader/DefaultLoader";

const SignInForm = () => {
  const [email, setEmail] = useState<string>("");
  const [password, setPassword] = useState<string>("");

  const {
    login,
    emailError,
    passwordError,
    error,
    loading,
    cleanRedirect,
    redirect,
  } = useSignIn();

  const router = useRouter();

  useEffect(() => {
    if (redirect) {
      router.push("/profile");
      cleanRedirect();
    }
  }, [redirect]);

  return (
    <form
      className="sign-in-form"
      onSubmit={(e) => {
        e.preventDefault();
        login(email, password);
      }}
    >
      <div className="sign-in-form__inputs">
        <InputWithLabel
          label="Email"
          value={email}
          onChange={(e) => setEmail(e.target.value)}
          placeholder="Введите email"
          error={emailError}
        />
        {emailError ? <p>{emailError}</p> : null}
        <InputWithLabel
          label="Пароль"
          value={password}
          onChange={(e) => setPassword(e.target.value)}
          placeholder="Введите пароль"
          secret
          error={passwordError}
        />
        {error ? <p>{error}</p> : null}
      </div>

      <CustomLink
        path="/forgot-password"
        style={{ justifySelf: "flex-end" }}
      >
        Забыли пароль?
      </CustomLink>

      <div className="sign-in-form__btns">
        <Button type="submit">
          {!loading ? "Войти" : <DefaultLoader />}
        </Button>
        <GoogleButton>Войти через Google</GoogleButton>
      </div>

      <div className="sign-in-form__no-account">
        <span>Еще нет аккаунта?</span>

        <CustomLink path="/sign-up">Зарегистрируйтесь</CustomLink>
      </div>
    </form>
  );
};

export default SignInForm;
