import { baseAPI } from "@/Shared/API/baseAPI";
import { IFetch } from "@/Shared/types";
import axios from "axios";
import { create } from "zustand";
import { IReport } from "./types";

interface IRatingStore extends IFetch {
  data: IReport;
  getRatings: () => Promise<void>;
}

export const useRating = create<IRatingStore>((set) => ({
  data: {
    count: 0,
    results: [],
  },
  loading: false,
  error: "",
  getRatings: async () => {
    try {
      set({ loading: true });

      const response = await axios.get<IReport>(`${baseAPI}/report/`);

      set({ data: response.data });
    } catch (error: any) {
      set({ error: error.message });
    } finally {
      set({ loading: false });
    }
  },
}));
